===============
Search Analysis
===============


.. image:: https://img.shields.io/pypi/v/search_analysis.svg
        :target: https://pypi.python.org/pypi/search_analysis

.. image:: https://img.shields.io/travis/MiriamPragmalingu/search_analysis.svg
        :target: https://travis-ci.com/MiriamPragmalingu/search_analysis

.. image:: https://readthedocs.org/projects/search-analysis/badge/?version=latest
        :target: https://search-analysis.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




The search analysis library contains multiple tools to help you analyze your search engine approach.


* Free software: MIT license
* Documentation: Coming soon


Features
--------

**Use-Case: Analyze Single Approach**

* Get Metrics: Precision, Recall, F-Score
* Find queries that perform especially bad/good
* Analyze false positives, false negatives and true positives
* For every query get score, field value, highlighting

**Use-Case Compare Two Approaches**

* Visualization of metrics side by side
* Find queries with biggest difference
* Analyze false positives, false negatives, true positives and calculate disjoint sets
* Get scores visualized side by side

(For now it's only possible to work with Elasticsearch)


Help
------------

For questions you can contact us via E-Mail or through our website (https://www.pragmalingu.de/).

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
